@@ -35,11 +35,11 @@ Geo::Coder::Free::OpenAddresses - Provides a geocoding functionality to the data
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $OLDCODE = 0;
 
 =head1 SYNOPSIS
@@ -121,6 +121,8 @@ sub geocode {
 	my %param;
 	if(ref($_[0]) eq 'HASH') {
 		%param = %{$_[0]};
+	} elsif(ref($_[0])) {
+		Carp::croak('Usage: geocode(location => $location)');
 	} elsif(@_ % 2 == 0) {
 		%param = @_;
 	} else {
@@ -128,7 +130,7 @@ sub geocode {
 	}
 
 	my $location = $param{location}
-		or Carp::croak("Usage: geocode(location => \$location)");
+		or Carp::croak('Usage: geocode(location => $location)');
 
 	# ::diag($location);
 
@@ -203,7 +205,7 @@ sub geocode {
 		if(my %addr = Geo::libpostal::parse_address($location)) {
 			# print Data::Dumper->new([\%addr])->Dump();
 			if($addr{'country'} && $addr{'state'} && ($addr{'country'} =~ /^(Canada|United States|USA|US)$/i)) {
-				if(my $street = $addr{'road'}) {
+				if($street = $addr{'road'}) {
 					$street = uc($street);
 					if($street =~ /(.+)\s+STREET$/) {
 						$street = "$1 ST";
@@ -648,8 +650,8 @@ sub geocode {
 		}
 	} elsif($location =~ /([a-z\s]+),?\s*(United States|USA|US|Canada)$/i) {
 		# Looking for a state/province in Canada or the US
-		my $state = $1;
-		my $country = $2;
+		$state = $1;
+		$country = $2;
 		if($country =~ /Canada/i) {
 			$country = 'CA';
 			if(length($state) > 2) {
